@@ -79,6 +79,8 @@ log_replies = os.environ.get('SIGMUND_LOG_REPLIES', False)
 openai_api_key = os.environ.get('OPENAI_API_KEY', None)
 anthropic_api_key = os.environ.get('ANTHROPIC_API_KEY', None)
 mistral_api_key = os.environ.get('MISTRAL_API_KEY', None)
+# Force dummy model for development purposes
+dummy_model = int(os.environ.get("SIGMUND_DUMMY_MODEL", False))
 # Supported models are currently:
 # - gpt-3.5
 # - gpt-4o
@@ -100,14 +102,14 @@ mistral_api_key = os.environ.get('MISTRAL_API_KEY', None)
 #   model
 model_config = {
     'openai': {
-        'condense_model': 'gpt-4.1-mini',
-        'public_model': 'gpt-4.1-mini',
-        'answer_model': 'gpt-4.1'
+        'condense_model': 'gpt-5-mini',
+        'public_model': 'gpt-5-nano',
+        'answer_model': 'gpt-5'
     },
-    'openai_o1': {
-        'condense_model': 'gpt-4.1-mini',
-        'public_model': 'gpt-4.1-mini',
-        'answer_model': 'o3'
+    'openai_thinking': {
+        'condense_model': 'gpt-5-mini',
+        'public_model': 'gpt-5-nano',
+        'answer_model': 'gpt-5-thinking'
     },
     'anthropic': {
         'condense_model': 'claude-4-sonnet',
@@ -117,7 +119,7 @@ model_config = {
     'anthropic_thinking': {
         'condense_model': 'claude-4-sonnet',
         'public_model': 'claude-3.5-haiku',
-        'answer_model': 'claude-4-opus-thinking'
+        'answer_model': 'claude-4-1-opus-thinking'
     },
     'mistral': {
         'condense_model': 'ministral-8b-2410',
@@ -127,7 +129,7 @@ model_config = {
     },
     'magistral': {
         'condense_model': 'ministral-8b-2410',
-        'public_model': 'gpt-4o-mini',
+        'public_model': 'gpt-5-nano',
         'answer_model': 'magistral-medium-latest',
         'vision_model': 'pixtral-large-latest'
     },
@@ -230,9 +232,6 @@ def validate_user(username, password):
     return user_validation.validate(username, password)
 
 
-login_failed_message = '__User name or password incorrect. Please try again.__'
-
-
 # SUBSCRIPTIONS
 #
 # Enable this to activate the Stripe-based subscription functionality.
