@@ -1,4 +1,5 @@
 from ._base_model import BaseModel
+from .. import config
 
 
 OPENAI_MODELS = {
@@ -6,6 +7,10 @@ OPENAI_MODELS = {
     'o3': 'o3',
     'o3-mini': 'o3-mini',
     'o4-mini': 'o4-mini',
+    'gpt-5-thinking': 'gpt-5',
+    'gpt-5': 'gpt-5',
+    'gpt-5-mini': 'gpt-5-mini',
+    'gpt-5-nano': 'gpt-5-nano',
     'gpt-4.1': 'gpt-4.1',
     'gpt-4.1-mini': 'gpt-4.1-mini',
     'gpt-4': 'gpt-4o',
@@ -22,27 +27,29 @@ ANTHROPIC_MODELS = {
     'claude-3.7-sonnet': 'claude-3-7-sonnet-latest',
     'claude-3.7-sonnet-thinking': 'claude-3-7-sonnet-latest',
     'claude-3.5-haiku': 'claude-3-5-haiku-latest',
-    'claude-4-sonnet': 'claude-sonnet-4-20250514',
-    'claude-4-sonnet-thinking': 'claude-sonnet-4-20250514',
-    'claude-4-opus': 'claude-opus-4-20250514',
-    'claude-4-opus-thinking': 'claude-opus-4-20250514',
+    'claude-4-sonnet': 'claude-sonnet-4-0',
+    'claude-4-sonnet-thinking': 'claude-sonnet-4-0',
+    'claude-4-opus': 'claude-opus-4-0',
+    'claude-4-opus-thinking': 'claude-opus-4-0',
+    'claude-4-1-opus': 'claude-opus-4-1',
+    'claude-4-1-opus-thinking': 'claude-opus-4-1',
 }
 
 
 def model(sigmund, model, **kwargs):
     """A factory function that returns a Model instance."""
+    if model.endswith('-thinking'):
+        kwargs['thinking'] = True
+    if model == 'dummy' or config.dummy_model:
+        from ._dummy_model import DummyModel
+        return DummyModel(sigmund, 'dummy', **kwargs)
     if model in OPENAI_MODELS:
         from ._openai_model import OpenAIModel
         return OpenAIModel(sigmund, OPENAI_MODELS[model], **kwargs)
     if model in ANTHROPIC_MODELS:
         from ._anthropic_model import AnthropicModel
-        if model.endswith('-thinking'):
-            kwargs['thinking'] = True
         return AnthropicModel(sigmund, ANTHROPIC_MODELS[model], **kwargs)
     if 'mistral' in model or 'ministral' in model or 'magistral' in model:
         from ._mistral_model import MistralModel
         return MistralModel(sigmund, model, **kwargs)
-    if model == 'dummy':
-        from ._dummy_model import DummyModel
-        return DummyModel(sigmund, **kwargs)
     raise ValueError(f'Unknown model: {model}')
