@@ -1,6 +1,5 @@
 from . import BaseModel
 from .. import config, utils
-import re
 import logging
 import json
 logger = logging.getLogger('sigmund')
@@ -10,11 +9,9 @@ class AnthropicModel(BaseModel):
     
     supports_not_done_yet = False
     
-    def __init__(self, sigmund, model, thinking=False, **kwargs):
+    def __init__(self, sigmund, model, **kwargs):
         from anthropic import Anthropic, AsyncAnthropic
-        super().__init__(sigmund, **kwargs)
-        self._thinking = thinking
-        self._model = model
+        super().__init__(sigmund, model, **kwargs)
         self._tool_use_id = 0
         self._client = Anthropic(api_key=config.anthropic_api_key)
         self._async_client = AsyncAnthropic(api_key=config.anthropic_api_key)
@@ -217,37 +214,3 @@ class AnthropicModel(BaseModel):
     def async_invoke(self, messages):
         return self._anthropic_invoke(self._async_client.messages.create,
                                       messages)
-
-    @staticmethod
-    def embed_thinking_block(signature: str | None, content: str | None) -> str:
-        """Embeds information about an Anthropic thinking block as an HTML element."""
-        sig = f'<div class="thinking_block_signature">{signature}</div>' if signature else ""
-        cont = f'<div class="thinking_block_content">{content}</div>' if content else ""
-        return sig + cont
-    
-    @staticmethod
-    def extract_thinking_block(content: str) -> [str, str | None, str | None]:
-        """
-        Extracts signature/content spans if present and returns a tuple:
-          (cleaned_content, signature, content)
-        """
-        sig_pattern = r'<div\s+class="thinking_block_signature">(.*?)</div>'
-        cont_pattern = r'<div\s+class="thinking_block_content">(.*?)</div>'
-        signature = None
-        thinking_content = None
-    
-        sig_match = re.search(sig_pattern, content)
-        if sig_match:
-            signature = sig_match.group(1)
-            content = re.sub(sig_pattern, '', content, count=1)
-    
-        cont_match = re.search(cont_pattern, content, re.MULTILINE | re.DOTALL)
-        if cont_match:
-            thinking_content = cont_match.group(1)
-            content = re.sub(cont_pattern, '', content, count=1,
-                             flags=re.MULTILINE | re.DOTALL)
-    
-        cleaned = content.strip()
-        if signature or thinking_content:
-            return cleaned, signature, thinking_content
-        return content, None, None
\ No newline at end of file
